Documentation
¶
Overview ¶
Package api provides functionality for making requests against the Vault API. This can be used by clients to perform actions manually that are not yet supported by vaultx.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type API ¶
type API interface {
// Write sends data to the Vault API.
Write(ctx context.Context, path string, vaultToken string, payload interface{}) (*Response, error)
// Read retrieves data from the Vault API.
Read(ctx context.Context, path string, vaultToken string) (*Response, error)
}
API makes requests against the Vault API.
Click to show internal directories.
Click to hide internal directories.